==> testcanarybot-0.7.3.tar.gz: testcanarybot-0.7.3/testcanarybot/databases.py <==
import sqlite3


class DBError(Exception):
    pass


class Database:
    def __init__(self, directory):
        self.directory = directory
        self.connection = sqlite3.connect(directory)
        self.cursor = self.connection.cursor()


    def request(self, request: str):
        self.cursor.execute(request)
        self.connection.commit()
        
        return self.cursor.fetchall()


    def close(self):
        self.connection.close()


class Databases:
    def __init__(self, names: list):
        self.upload(names)


    def check(self, name):
        response = [*self.__dbs.keys(), 
                *[i.directory for i in self.__dbs.values()]]

        return name in response 


    def upload(self, names):
        self.__dbs = {}
        self.add(names)


    def get(self, name):
        check = type(name)
        if check == tuple:
            if not self.check(name[0]):
                raise DBError("This DB does not exist")

            else:
                return self.__dbs[name[1]]

        elif check == str:
            if not self.check(name):
                raise DBError("This DB does not exist")

            else:
                return self.__dbs[name]



    def add(self, names): 
        check = type(names)

        if check == list:
            for name in names:
                if self.check(name[0]):
                    raise DBError("This DB already exists")

                else:
                    self.__dbs[name[0]] = Database(name[1])

        elif check == tuple:
            if self.check(names[0]):
                raise DBError("This DB already exists")

            else:
                self.__dbs[names[0]] = Database(names[1])

        elif check == str:
            if self.check(names):
                raise DBError("This DB already exists")

            else:
                self.__dbs[names] = Database(names)
        
        else:
            raise DBError("Incorrect type of 'names'")



if __name__ == "__main__":
    try:
        test = Databases([("test", "DatabaseTest.db")])

    except DBError as e:
        print(e)

==> testcanarybot-0.7.4.tar.gz: testcanarybot-0.7.4/testcanarybot/databases.py <==
import sqlite3
import os

class DBError(Exception):
    pass


class Database:
    def __init__(self, directory):
        self.directory = directory
        self.connection = sqlite3.connect(directory)
        self.cursor = self.connection.cursor()


    def request(self, request: str):
        self.cursor.execute(request)
        self.connection.commit()
        
        return self.cursor.fetchall()


    def close(self):
        self.connection.close()


class Databases:
    def __init__(self, names: list):
        self.upload(names)


    def check(self, name):
        response = [*self.__dbs.keys(), 
                *[i.directory for i in self.__dbs.values()]]

        return name in response 


    def upload(self, names):
        self.__dbs = {}
        self.add(names)


    def get(self, name):
        check = type(name)
        if check == tuple:
            if not self.check(name[0]):
                raise DBError("This DB does not exist")

            else:
                return self.__dbs[name[1]]

        elif check == str:
            if not self.check(name):
                raise DBError("This DB does not exist")

            else:
                return self.__dbs[name]



    def add(self, names): 
        check = type(names)

        if check == list:
            for name in names:
                if self.check(name[0]):
                    raise DBError("This DB already exists")

                else:
                    self.__dbs[name[0]] = Database(os.getcwd() + '\\assets\\' + name[1])

        elif check == tuple:
            if self.check(names[0]):
                raise DBError("This DB already exists")

            else:
                self.__dbs[names[0]] = Database(os.getcwd() + '\\assets\\' + names[1])

        elif check == str:
            if self.check(names):
                raise DBError("This DB already exists")

            else:
                self.__dbs[names] = Database(os.getcwd() + '\\assets\\' + names)
        
        else:
            raise DBError("Incorrect type of 'names'")



if __name__ == "__main__":
    try:
        test = Databases([("test", "DatabaseTest.db")])

    except DBError as e:
        print(e)
